@@ -82,24 +82,24 @@ class Document(object):
     def dump_draft(self):
         buf = StringIO.StringIO()
         for key in self.attr_names():
-            buf.write("%s=%s\n" % (key, _enc(self.attrs[key])))
+            buf.write(u"%s=%s\n" % (key, _enc(self.attrs[key])))
         if self.kwords:
-            buf.write("%%VECTOR")
+            buf.write("%%VECTO")
             for key, value in self.kwords.iteritems():
-                buf.write("\t%s\t%s" % (key, value))
+                buf.write(u"\t%s\t%s" % (key, value))
             buf.write("\n")
         if self.score >= 0:
             buf.write("%%SCORE\t\d\n", self.score)
         buf.write("\n")
         if self.dtexts:
-            buf.write("\n".join(_enc(self.dtexts)))
+            buf.write("\n".join(self.dtexts))
             buf.write("\n")
         if self.htexts:
             buf.write("\t")
-            buf.write("\n\t".join(_enc(self.htexts)))
+            buf.write("\n\t".join(self.htexts))
             buf.write("\n")
 
-        return buf.getvalue()
+        return buf.getvalue().encode("utf-8")
 
 
 
@@ -191,7 +191,7 @@ class NodeResult(object):
         return len(self.docs)
 
     def get_doc(self, index):
-        if index < 0 or index >= self.docNum():
+        if index < 0 or index >= self.doc_num():
             return None
         return self.docs[index]
 
@@ -575,6 +575,7 @@ def _escape(s):
 
 
 def _enc(s):
-    if type(s) == str:
-        s = s.decode("utf-8")
     return s
+#     if type(s) == str:
+#         s = s.decode("utf-8")
+#     return s
